@@ -73,7 +73,7 @@ pass.tile.plot<-function(x,subset=1:ncol(x@data),variate_names=TRUE)
 #'
 #' @rdname plot-methods
 #'
-#' @aliases plot,pass.class,ANY-method
+#' @aliases plot,pass.class-method
 #'
 #' @export
 setMethod("plot",signature=list("pass.class"),function(x,subset,variate_names,tile_plot)
@@ -140,7 +140,7 @@ setMethod("plot",signature=list("pass.class"),function(x,subset,variate_names,ti
 #' @aliases summary,pass.class-method
 #'
 #' @export
-setMethod("summary",signature=list("pass.class"),function(object)
+setMethod("summary",signature=list("pass.class"),function(object,...)
 {
     cat("PASS detecting change in mean","\n")
     cat("observations = ",nrow(object@data),"\n",sep="")
